@@ -17,6 +17,7 @@
 #pragma once
 
 #include <folly/IntrusiveList.h>
+#include <folly/SocketAddress.h>
 #include <folly/io/async/DelayedDestruction.h>
 #include <folly/io/async/HHWheelTimer.h>
 
@@ -71,6 +72,12 @@ class ManagedConnection : public folly::HHWheelTimer::Callback,
    */
   virtual bool isBusy() const = 0;
 
+  /**
+   * Returns socket address of the peer
+   */
+  [[nodiscard]] virtual const folly::SocketAddress& getPeerAddress()
+      const noexcept = 0;
+
   /**
    * Get the idle time of the connection. If it returning 0, that means this
    * idle connection will never be dropped during pre load shedding stage.
@@ -149,6 +156,10 @@ class ManagedConnection : public folly::HHWheelTimer::Callback,
   virtual folly::Optional<std::chrono::milliseconds>
   getLastActivityElapsedTime() const;
 
+  [[nodiscard]] std::chrono::steady_clock::time_point getCreationTime() const {
+    return creationTime_;
+  }
+
  protected:
   ~ManagedConnection() override;
 
@@ -171,6 +182,8 @@ class ManagedConnection : public folly::HHWheelTimer::Callback,
   ConnectionAgeTimeout connectionAgeTimeout_;
   folly::Optional<std::chrono::steady_clock::time_point> latestActivity_;
 
+  const std::chrono::steady_clock::time_point creationTime_;
+
   folly::SafeIntrusiveListHook listHook_;
 };
 
